#!/bin/bash
# Descarga y procesa paradas de la EMT
# Santiago Crespo 2022

#wget http://opendata.emtmadrid.es/data/opendata/XML/NodesLines.xml

TMPDIR="/tmp/emtstops"
date
INITIALDIR=`pwd`
mkdir -p $TMPDIR
rm -f $TMPDIR/*

echo "Descargamos coordenadas y ID's del CRTM y reproyectamos. Usamos estas coordenadas cuando sea posible"
./reproyecta_coordenadas_emt_crtm.sh && cp emt-stops-4326.csv $TMPDIR/ && echo "Reproyección completada con éxito" || exit 1

cd $TMPDIR

# Para el timestamp
DIA=`date +%Y-%m-%d`
HORA=`date +%H:%M:%S`

wget -nv http://servicios.emtmadrid.es:8080/GTFS/transitEMT.zip
unzip transitEMT.zip
grep -v "stop_id" stops.txt > a ; mv a stops.txt

echo '<?xml version="1.0"?>
<osm version="0.6" generator="emt_bus_stop.sh">' > emt_stops.osm

ID="70000380000"

# PENDIENTE: por ahora usamos la fecha de la descarga
SOURCEDATE=$DIA

echo "Procesando..."
while IFS='' read -r linea; do

  REF=`echo $linea | awk -F ',' '{print $1}'`
  NAME=`echo $linea | awk -F ',' '{print $3}'`
  URL=`echo $linea | awk -F ',' '{print $8}'`
  
  if grep -q '"'$REF'"' emt-stops-4326.csv ; then # Si tenemos coordenadas reproyectadas del CRTM, usamos esas
    LAT=`grep '"'$REF'"' emt-stops-4326.csv | awk -F ',' '{print $3}'`
    LON=`grep '"'$REF'"' emt-stops-4326.csv | awk -F ',' '{print $2}'`
  else # Si no hay match, usamos las coordenadas de la EMT
    LAT=`echo $linea | awk -F ',' '{print $5}'`
    LON=`echo $linea | awk -F ',' '{print $6}'`
fi 
  
  echo '<node version="1" changeset="1" timestamp="'$DIA'T'$HORA'Z" id="'$ID'" lat="'$LAT'" lon="'$LON'" visible="true">
<tag k="highway" v="bus_stop"/>
<tag k="network" v="EMT Bus"/>
<tag k="source" v="EMT Madrid"/>
<tag k="source:date" v="'$SOURCEDATE'"/>
<tag k="operator" v="Empresa Municipal de Transportes de Madrid"/>
<tag k="ref" v="'$REF'"/>
<tag k="name" v="'$NAME'"/>
</node>
' >> emt_stops.osm

# <tag k="url" v="'$URL'"/>'

  ID=$((ID + 1))

done < stops.txt

echo '</osm>' >> emt_stops.osm && cp emt_stops.osm "$INITIALDIR/emt_stops.osm" && cd "$INITIALDIR" && echo "emt_stops.osm creado!" && date && exit 0


